import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleOrdinal,
  schemeCategory10
} from 'd3';

import { dropDownMenu } from './dropDownMenu';
import { scatterPlot } from './scatterPlot';
import { loadData } from './loadData';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const color = scaleOrdinal(schemeCategory10);

const cValue = data => data['Indicator_desc'];

let data;
let xColumn;
let yColumn;
let selectedIndicator = null;
let Indicators;

const onXColumnClicked = column => {
  xColumn = column;  
  render();
};

const onYColumnClicked = column => {
  yColumn = column;  
  render();
};

const onClick = d => {
  selectedIndicator = d;
  render();  
};


loadData().then(data => {
  menuItems = data;
  xColumn = data.columns[4];
  yColumn = data.columns[3];
  render();
});

const render = () => {
  
  select('#x-menu')
    .call(dropDownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
  });
  
  select('#y-menu')
    .call(dropDownMenu, {
      options: data.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
  });
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    circleRadius: 4,
    yAxisLabel: yColumn,
    margin: { top: 20, right: 35, bottom: 88, left: 100 },
    width,
    height,
    data: menuItems,
    color,
    cValue,
    selectedIndicator
  });
  
  svg.call(colorLegend, {
    color,
    width,
    selectedIndicator,
    onClick
  });
  


};